@@ -620,17 +620,12 @@ class MoveGroupCommander(object):
         """Return a tuple of the motion planning results such as
         (success flag : boolean, trajectory message : RobotTrajectory,
          planning time : float, error code : MoveitErrorCodes)"""
-        if type(joints) is JointState:
-            self.set_joint_value_target(joints)
-
+        if type(joints) is str:
+            self.set_joint_value_target(self.get_remembered_joint_values()[joints])
         elif type(joints) is Pose:
             self.set_pose_target(joints)
-
         elif joints is not None:
-            try:
-                self.set_joint_value_target(self.get_remembered_joint_values()[joints])
-            except MoveItCommanderException:
-                self.set_joint_value_target(joints)
+            self.set_joint_value_target(joints)
 
         (error_code_msg, trajectory_msg, planning_time) = self._g.plan()
 
@@ -685,12 +680,15 @@ class MoveGroupCommander(object):
         path.deserialize(ser_path)
         return (path, fraction)
 
-    def execute(self, plan_msg, wait=True):
+    def execute(self, trajectory, wait=True):
         """Execute a previously planned path"""
+        if not hasattr(trajectory, "joint_trajectory"):
+            trajectory = RobotTrajectory(joint_trajectory=trajectory)
+
         if wait:
-            return self._g.execute(conversions.msg_to_string(plan_msg))
+            return self._g.execute(conversions.msg_to_string(trajectory))
         else:
-            return self._g.async_execute(conversions.msg_to_string(plan_msg))
+            return self._g.async_execute(conversions.msg_to_string(trajectory))
 
     def attach_object(self, object_name, link_name="", touch_links=[]):
         """Given the name of an object existing in the planning scene, attach it to a link. The link used is specified by the second argument. If left unspecified, the end-effector link is used, if one is known. If there is no end-effector link, the first link in the group is used. If no link is identified, failure is reported. True is returned if an attach request was succesfully sent to the move_group node. This does not verify that the attach request also was successfuly applied by move_group."""
